Optimize line for multi-turn tracking speed
===========================================

When the tracker is used for multi-turn tracking, the line and tracker can be
optimized to increase the tracking speed. This can be done with the
:meth:`Line.optimize_for_tracking` method, as shown in the following example.

See also: :meth:`Line.optimize_for_tracking`

.. literalinclude:: generated_code_snippets/optimized_tracker.py
   :language: python